package EFS::CLI::PlatformInstanceAlias;

use strict;
use warnings;
use English;

use base q{EFS::CLI};
use base q{EFS::DBI};
use Params::Validate qw( :all );

sub define {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name             => { type => SCALAR },
        platforminstance => { type => SCALAR },
    });

    $class->assert_platform_unused( $args{name} );

    my $platform_instance_rs = $class->get_resultset( q{PlatformInstance} );
    my $instance = $platform_instance_rs->retrieve_bynames_assert(
        name => $args{platforminstance},
    );

    my $resultset = $class->get_resultset;
    my ($alias)   = $resultset->search({ name => $args{name} });

    if ( $alias ) {
        STDOUT->print(
            qq{$args{name} is already an alias for $args{platforminstance}\n},
        );
    } else {
        $alias = $resultset->create({
            name             => $args{name},
            platforminstance => $instance->id,
        });
        STDOUT->print(
            qq{Defined $args{name} as an alias for $args{platforminstance}\n},
        );
    }

    return $alias;

}

sub undef {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name => { type => SCALAR },
    });

    my $resultset = $class->get_resultset;

    my $alias = $resultset->retrieve_bynames_assert( name => $args{name} );

    if ( my @installs = $alias->installs ) {
        die(
            qq{Unable to undef platform instance alias '$alias',\n},
            qq{as the following installs use this name:\n\t},
            join(qq{\n\t}, @installs ), qq{\n},
        );
    }

    $alias->delete;

    STDOUT->print( qq{Undefined platform instance alias $args{name}\n} );

    return 1;

}

sub display {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name => { type => SCALAR, optional => 1 },
    });

    my $resultset = $class->get_resultset;

    if ( $args{name} ) {
        my $alias = $resultset->retrieve_bynames_assert( name => $args{name} );
        $class->display_objects( objects => [ $alias ] );
    } else {
        $class->display_objects( objects => [ $resultset->all ] );
    }

    return 1;

}

sub history {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name => { type => SCALAR },
        %EFS::CLI::History::validation_specs,
    });

    $args{platforminstancealias} = delete $args{name};

    return EFS::CLI::History->history(%args);

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
