package EFS::CLI::Region;

use strict;
use warnings;
use English;

use base q{EFS::CLI};
use base q{EFS::DBI};
use Params::Validate qw( :all );

sub define {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name        => { type => SCALAR },
        description => { type => SCALAR },
    });

    my $resultset = $class->get_resultset;

    my ($region) = $resultset->search( { name => $args{name} } );

    if ($region) {

        STDOUT->print( qq{Region '$region' is already defined\n} );

        if ( $region->description ne $args{description} ) {
            $region->set_column( description => $args{description} );
            $region->update;
            STDOUT->print( qq{Updated description of region $args{name}\n} );
        }

    }
    else {

        $region = $resultset->create({
            name        => $args{name},
            description => $args{description},
        });

        STDOUT->print( qq{Defined region '$args{name}'\n} );

    }

    return $region;

}

sub undef {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name => { type => SCALAR },
    });

    my $resultset = $class->get_resultset;

    my $region = $resultset->retrieve_bynames_assert( name => $args{name}, );

    if ( my @campuses = $region->campuses ) {
        die(
            qq{Unable to undef region $args{name}, because it has the\n},
            qq{following campuses:\n\t},
            join ( qq{\n\t}, map { $_->name } @campuses ),
            qq{\n},
        );
    }

    $region->attrs->delete_all;
    $region->delete;

    STDOUT->print( qq{Undefined region $args{name}\n} );

    return 1;

}

sub display {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name => { type => SCALAR, optional => 1 },
    });

    my $resultset = $class->get_resultset;

    if ( not $args{name} ) {
        $class->display_objects( objects => [ $resultset->all ] );
        return 1;
    }

    my $region = $resultset->retrieve_bynames_assert( name => $args{name} );

    $class->display_objects( objects => [$region] );

    if ( my @attrs = $region->attrs ) {
        $attrs[0]->display_objects( objects => \@attrs );
    }

    if ( my @campuses = $region->campuses ) {
        $campuses[0]->display_objects( objects => \@campuses );
    }

    if ( my @cells = $region->cells ) {
        $cells[0]->display_objects( objects => \@cells );
    }

    return 1;

}

sub history {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name => { type => SCALAR },
        %EFS::CLI::History::validation_specs,
    });

    $args{region} = delete $args{name};

    return EFS::CLI::History->history(%args);

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
