package EFS::Config::Server;

use strict;
use warnings;
use English;

use Moose;
use Params::Validate qw( :all );
use Config::Tiny;

has q{_data} => (
    is       => q{ro},
    isa      => q{Config::Tiny},
    init_arg => q{_data},
);

{

    sub BUILDARGS {

        my ($class, $args_ref) = @_;

        $args_ref //= {};

        my @args = %{ $args_ref };

        my (%args) = validate( @args, {
            file => { type     => SCALAR,
                      default  => q{/etc/efs/server.conf},
                      optional => 1 },
        });

        my $config = Config::Tiny->read( $args{file} );

        if ( not $config->{database} ) {
            die(
                qq{Invalid config file: $args{file}\n},
                qq{Missing required section 'database'\n},
            );
        }

        foreach my $required ( qw( connect rwuser ) ) {
            if ( not $config->{database}->{$required} ) {
                die(
                    qq{Invalid config file: $args{file}\n},
                    qq{Missing required database parameter '$required'\n},
                );
            }
        }

        return { _data => $config };
    }

    sub get_value {
        my ($self,$section,$key) = @_;
        return $self->_data->{$section}->{$key};
    }

    sub get_section {
        my ($self,$section) = @_;
        return if not $self->_data->{$section};
        return %{ $self->_data->{$section} };
    }

}

no Moose;
__PACKAGE__->meta->make_immutable;
1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
