package EFS::DBI::Result::EFSServer;

use strict;
use warnings;
use English;

use base q{EFS::DBI::Result};

use EFS::FQDN qw( fqdn );

__PACKAGE__->load_components(qw/+EFS::DBI::Prefix Core/);

__PACKAGE__->table(q{efsserver});

__PACKAGE__->add_columns(qw( name hosttype ));
__PACKAGE__->add_columns(
    id => { __PACKAGE__->get_id_column_attrs },
);
__PACKAGE__->set_primary_key(q{id});
__PACKAGE__->sequence(q{efsserver_seq});

__PACKAGE__->has_many(
    efsserver_cell => q{EFS::DBI::Result::EFSServerCell},
    q{efsserver}
);
__PACKAGE__->many_to_many( q{cells} => q{efsserver_cell}, q{cell} );

__PACKAGE__->has_many( attrs => q{EFS::DBI::Result::EFSServerAttrs} );

sub object_id {
    return shift->name;
}

#
# This can be improved...  We still need a class method that assumes
# the localhost, but we also need an instance method, so we can easily
# check whether or not a given efsserver supports a given cell.
#
sub supports_cell {
    my $self = shift;
    my $cell = shift;
    my $resultset = $self->get_resultset(q{EFSServerCell});
    my ($supports) = $resultset->search({
        efsserver => $self->id,
        cell      => $cell->id,
    });
    return $supports;
}

sub is_localhost {

    my $self = shift;

    my $name = $self->name;
    my $fqdn = fqdn;

    if ( $self->name eq $fqdn ) {
        return 1;
    }
    else {
        return 0;
    }

}

sub exposed_cells {
    return grep { not $_->hidden } shift->cells;
}

# NOTE: These can be called as instance methods, with no argument (EFS::RPC),
# or as class methods, by passing the fqdn (efsd).

sub get_ssl_keyfile {
    my $self = shift;
    my $name = shift || $self->name;
    return qq{/var/efs/ssl/$name-key.pem};
}

sub get_ssl_certfile {
    my $self = shift;
    my $name = shift || $self->name;
    return qq{/var/efs/ssl/$name-cert.pem};
}

sub get_ca_certfile {
    return q{/var/efs/etc/cacert.pem};
}

sub get_crl_file {
    return q{/var/efs/etc/crl.pem};
}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
