package EFS::DBI::Result::InstallAuditState;

use strict;
use warnings;
use English;

use base q{EFS::DBI::Result};

use Date::Format;

__PACKAGE__->load_components( qw/+EFS::DBI::Prefix Core/ );

__PACKAGE__->table( q{install_auditstate} );

__PACKAGE__->add_columns( qw( install name audittime status ) );
__PACKAGE__->add_columns(
    id => { __PACKAGE__->get_id_column_attrs },
);
__PACKAGE__->set_primary_key( q{id} );
__PACKAGE__->sequence( q{install_auditstate_seq} );

__PACKAGE__->belongs_to( install => q{EFS::DBI::Result::Install} );

sub metaproj {
    return shift->install->metaproj;
}

sub project {
    return shift->install->project;
}

sub release {
    return shift->install->release;
}

# XXX: We were putting these into the CLI or ResultSet classes, but now I'm
# not so sure.
sub display_columns {
    return qw( metaproj project release install name audittime status );
};

sub display_translate {

    my $class = shift;

    my ($key,$value) = @_;

    if ( $key eq q{audittime} && $value =~ m/\A \d{10} \z/msx ) {
        return time2str(q{%Y-%m-%d %H:%M:%S (GMT)}, $value, q{GMT});
    } else {
        return $value;
    }

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
