package EFS::DBI::Result::Metaproj;

use strict;
use warnings;
use English;

use base q{EFS::DBI::Result};
use base q{EFS::DistableObject};

__PACKAGE__->load_components( qw/+EFS::DBI::Prefix Core/ );

__PACKAGE__->table( q{metaproj} );

__PACKAGE__->add_columns(
    id            => { __PACKAGE__->get_id_column_attrs },
    name          => { efs_column_group => [qw( display )] },
    username      => { efs_column_group => [qw( display )] },
    groupname     => { efs_column_group => [qw( display )] },
    owner_list    => { efs_column_group => [qw( display )] },
    notify_list   => { efs_column_group => [qw( optional )] },
    devvolume     => { efs_column_group => [qw( optional )] },
    distvolume    => { efs_column_group => [qw( optional )] },
    noworldaccess => { efs_column_group => [qw( access )] },
    distgroup     => { efs_column_group => [qw( access )] },
);
__PACKAGE__->set_primary_key( q{id} );
__PACKAGE__->sequence( q{metaproj_seq} );

__PACKAGE__->belongs_to( devvolume  => q{EFS::DBI::Result::AFSVolume} );
__PACKAGE__->belongs_to( distvolume => q{EFS::DBI::Result::AFSVolume} );

__PACKAGE__->has_many( projects => q{EFS::DBI::Result::Project} );

__PACKAGE__->has_many( grouprights => q{EFS::DBI::Result::GroupRights} );
__PACKAGE__->has_many( userrights  => q{EFS::DBI::Result::UserRights} );
__PACKAGE__->has_many( attrs       => q{EFS::DBI::Result::MetaprojAttrs} );

sub display_columns {
    return qw( name username groupname spaceused
               filecount dircount linkcount);
}

sub releases {
    return map { $_->releases(@_) } shift->projects;
}

sub active_releases {
    return map { $_->active_releases(@_) } shift->projects;
}

sub releasealiases {
    return map { $_->releasealiases(@_) } shift->projects;
}

sub installs {
    return map { $_->installs(@_) } shift->releases;
}

sub subitems {
    return shift->projects;
}

sub container { return; }

sub get_path {
    my ($self,$pathtype) = @_;
    $pathtype ||= q{dist};
    return qq{/efs/$pathtype/} . $self->name;
}

sub assert_not_disabled {

    my $self = shift;

    if ( my $disabled   = $self->is_disabled ) {
        die qq{Metaproj '$self' is disabled: $disabled\n};
    }

    return;
}

sub get_diststate {
    my $self = shift;
    return EFS::Diststate::Metaproj->new({metaproj => $self});
}

sub display_translate {

    my $class = shift;
    my ($key,$value) = @_;

    if ( $key eq q{spaceused} ) {
        return $class->size_shorthand($value);
    } else {
        return $value;
    }

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
