package EFS::DBI::ResultSet::History;

use strict;
use warnings;
use English;

use base q{EFS::DBI::ResultSet};

use Params::Validate qw( :all );

sub retrieve_assert {

    my $self = shift;

    my (%args) = validate( @_, {
        id => { type => SCALAR },
    });

    my ($history) = $self->search({ id => $args{id} });

    if ( not $history ) {
        die qq{No such history record for id '$args{id}'\n};
    }

    return $history;

}

sub validate_data {

    my $class = shift;
    my %data  = @_;

    my %history = ();

    my %type2subclass = (
        filetype  => q{Fileshare},
        target    => q{ReleaseAlias},
        backwards => q{Platform},
        emulates  => q{Platform},
        stage     => q{Release},
    );

    my %columns = map { $_ => 1 } @EFS::DBI::Result::History::other_keys;

    foreach my $type ( sort keys %data ) {

        my $type_subclass =
            $type2subclass{$type} ||
                EFS::DBI->type2subclass($type) ||
                      die qq{Unrecognized type '$type'\n};

        my $type_class  = q{EFS::DBI::ResultSet::} . $type_subclass;

        if ( $type_class->can(q{validate_data}) ) {
            $type_class->validate_data( $type => $data{$type} );
        }

        if ( $columns{$type} ) {
            $history{$type} = $data{$type};
        }

    }

    return %history;

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
