package EFS::DBI::ResultSet::PlatformAlias;

use strict;
use warnings;
use English;

use base q{EFS::DBI::ResultSet};

use Params::Validate qw( :all );

sub validate_data {

    my $class = shift;
    my %data = @_;

    foreach my $type ( qw( platform platformalias ) ) {
        next unless exists $data{$type};
        next if $data{$type} eq q{NULL};  # Special case
        ## no critic ProhibitEnumeratedClasses
        # we really do want a-z here; [:lower:] would be effected by locale
        $data{$type} =~ m/\A [-a-z0-9\.]+ \z/msx ||
            die(
                qq{Invalid $type name '$data{$type}'\n},
                q{Must consist solely of lower case alphanumeric },
                qq{characters, dashes and/or dots\n}
            );
    }

    return;
}

sub retrieve_bynames_assert {

    my $self = shift;

    my (%args) = validate( @_, {
        name => { type => SCALAR },
    });

    my ($platformalias) = $self->search({ name => $args{name} });

    if ( not $platformalias ) {
        die qq{No such platform alias '$args{name}'\n};
    }

    return $platformalias;

}

sub get_flattened_data {

    my $self = shift;

    my $data = {};

    foreach my $alias ( $self->all ) {
        $data->{ $alias->name } = $alias->platform->name;
    }

    return $data;

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
