package EFS::DBI::ResultSet::Project;

use strict;
use warnings;
use English;

use base q{EFS::DBI::ResultSet};

use EFS::FQDN qw(fqdn);

use Params::Validate qw( :all );

sub validate_data {

    my $class = shift;
    my %data  = @_;

    if ( exists $data{project} ) {
        $data{project} =~ m/\A [-\w\.]+ \z/msx || die(
            qq{Invalid project name '$data{project}'\n},
            q{Must consist solely of alphanumeric characters, },
            qq{underscores, dashes and/or dots\n}
        );
    }

    return 1;

}

sub retrieve_bynames_assert {

    my $self = shift;

    my (%args) = validate( @_, {
        metaproj => { type => SCALAR },
        name     => { type => SCALAR },
        disabled => { type => BOOLEAN, optional => 1 },
        movelock => { type => BOOLEAN, optional => 1 },
    });

    my $metaproj_rs = EFS::DBI->get_resultset( q{Metaproj} );

    my $metaproj = $metaproj_rs->retrieve_bynames_assert(
        name     => $args{metaproj},
        disabled => $args{disabled},
    );

    my ($project) = $self->search({
        metaproj => $metaproj->id,
        name     => $args{name},
    });

    if ( not $project ) {
        die qq{No such project '$metaproj/$args{name}'\n};
    }

    if ( not $args{movelock} and my $movelock = $project->movelock ) {

        my ($movehost,$movepid,$fromcell,$tocell) = split( m/:/msx, $movelock );

        if ( $movehost ne fqdn || $movepid != $PID ) {
            die(
                qq{Project '$project' is currently being moved\n},
                qq{from $fromcell to $tocell\n},
                qq{by process $movepid on $movehost\n},
            );
        }

    }

    if ( not $args{disabled} ) {
        $project->assert_not_disabled;
    }

    return $project;

}

sub retrieve_bynames {

    my $self = shift;

    my (%args) = validate( @_, {
        metaproj => { type => SCALAR },
        name     => { type => SCALAR },
        disabled => { type => BOOLEAN, optional => 1 },
    });

    my $metaproj_rs = EFS::DBI->get_resultset( q{Metaproj} );

    my $metaproj = $metaproj_rs->retrieve_bynames(
        name     => $args{metaproj},
        disabled => $args{disabled},
    );

    if ( not $metaproj ) {
        return;
    }

    my ($project) = $self->search({
        metaproj => $metaproj->id,
        name     => $args{name},
    });

    return $project;

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
