#!/usr/bin/env perl

use strict;
use warnings;
use English;

use Test::More;
use Test::Exception;
use List::MoreUtils qw(all);

use lib q{test/lib};
use EFS::Test::Config;

use blib;
use EFS;

## no critic: RequireExtendedFormatting

$ENV{EFS_RPC_DEBUG} = 1;

my $config = EFS::Test::Config->new;

my $name_local  = $config->get_value( q{LocalDevCell},  q{name} );
my $name_remote = $config->get_value( q{RemoteDevCell}, q{name} );
my $name_prod   = $config->get_value( q{LocalProdCell}, q{name} );

my @cells = EFS::DBI->handle_cell_arguments(
    cells => $name_local
);

ok( $#cells == 0, q{One cell expands to one cell} );

ok( ref $cells[0] && $cells[0]->isa(q{EFS::DBI::Result::Cell}),
    q{cell name expands to an object} );

@cells = EFS::DBI->handle_cell_arguments(
    cells => qq{$name_local,$name_remote},
);

ok( $#cells == 1, q{Two cells expands to two cells} );

@cells = EFS::DBI->handle_cell_arguments(
    cells => qq{$name_local,$name_remote,$name_prod},
);

ok( $#cells == 2, q{Three cells expands to three  cells} );

@cells = EFS::DBI->handle_cell_arguments(
    cells           => $name_prod,
    include_parents => 1,
);

ok( $#cells == 1, q{One prod with parents expands to two cells} );

@cells = EFS::DBI->handle_cell_arguments(
    cells           => qq{$name_local,$name_prod},
    include_parents => 1,
);

ok( $#cells == 1, q{dev and prod with parents expands to two cells, no dups} );

@cells = EFS::DBI->handle_cell_arguments(
    celltype => q{dev},
);

ok( $#cells == 0, q{celltype of dev returns one cell only with no default_scope} );

@cells = EFS::DBI->handle_cell_arguments(
    celltype      => q{dev},
    default_scope => q{global},
);

ok( $#cells == 1, q{celltype of dev returns two cells with default_scope of global} );

@cells = EFS::DBI->handle_cell_arguments(
    celltype => q{prod},
);

ok( $#cells == 1, q{celltype of prod returns two cells with no default_scope} );

done_testing();
exit 0;
