#!/usr/bin/env perl
use strict;
use warnings;
use English;

use Config;

use blib;
use EFS;

use lib q{test/lib};
use EFS::Test;
use EFS::Test::Config;

use Test::More tests => 7;
use IO::File;

my $config        = EFS::Test::Config->new;

my $rdc_efsserver = $config->get_value( q{RemoteDevCell}, 'efsserver' );
my $sshcmd        = $config->get_value( q{Global}, 'sshcmd' )
    . q{ -o NumberOfPasswordPrompts=0};

my $ldc_efsserver = $config->get_value( q{LocalDevCell}, q{efsserver} );

SKIP: {

    if ( not $config->get_value( q{Security}, q{kerberos_realm} ) ) {
        skip q{Kerberos tests not configured}, 1;
    }

    ## no critic: RequireInterpolationOfMetachars
    my $krb5ccname = qq{/var/tmp/krb5_efstest_$PID};
    $ENV{KRB5CCNAME} = qq{FILE:$krb5ccname};
    system qq{kinit -k -t /var/kerberos/keytabs/efsops.keytab efsops};
    ok( $CHILD_ERROR == 0, q{Acquired efsops credentials for this test} );

}

my $sshid_current = EFS::CLI::EFSServer->sshid;
my $sshid_test    = q{/var/tmp/.efsd.ssh.key};

system( qq{cp $sshid_current $sshid_test} );
ok( $CHILD_ERROR == 0, q{Copied existing ssh key for testing purposes} );

ok( EFS::CLI::EFSServer->newkeys( bootstrap => 1 ),
    q{Regenerated new ssh keys} );

ok( EFS::CLI::EFSServer->purgekeys, q{Purged old keys} );

my $ssh_error = qx{ $sshcmd -i $sshid_test $rdc_efsserver true 2>&1 };
ok( $CHILD_ERROR, q{ssh command failed as expected} );

ok( $ssh_error =~ /^Permission \s+ denied/msx, q{ssh error matches} );

ok( unlink ($sshid_test), q{Unlinked copy of ssh key} );

END {
    my $krb5ccname = qq{/var/tmp/krb5_efstest_$PID};
    if ( $krb5ccname && -f $krb5ccname ) {
        system q{kdestroy};
        $CHILD_ERROR and warn qq{Unable to destroy kerberos credentials\n};
    }
}
