#!/usr/bin/env perl

use strict;
use warnings;
use English;

use Test::More tests => 5;

use lib q{test/lib};
use EFS::Test;

my $test = EFS::Test->new( as_user => q{efsops} );
my $config = $test->get_config;

my $root_domain = $config->get_value( q{Global}, q{root_domain} );
my $region      = $config->get_value( q{Global}, q{region} );
my $campus      = $config->get_value( q{Global}, q{campus} );
my $location    = $config->get_value( q{Global}, q{location} );

my $fstype = $config->get_value( q{Filesystem}, q{type} );

my $ldc_name      = $config->get_value( q{LocalDevCell}, q{name} );
my $ldc_shortname = $config->get_value( q{LocalDevCell}, q{shortname} );

my $rdc_name      = $config->get_value( q{RemoteDevCell}, q{name} );
my $rdc_shortname = $config->get_value( q{RemoteDevCell}, q{shortname} );

my $tmp_name      = qq{c.$location.$campus.$region.$root_domain};
my $tmp_shortname = qq{c.$location};

$test->efs_test_command(
    command => qq{efs define cell $region $campus $location c test $fstype $ldc_shortname},
);

$test->efs_test_command(
    command => qq{efs define cell $region $campus $location c test $fstype $ldc_shortname},
    expect  => [
        qq{Cell $tmp_name is already defined with:},
        qq{Parentcell => $ldc_name},
    ],
);

# Check that we can't change the celltype

$test->efs_test_command(
    command => qq{efs define cell $region $campus $location c prod $fstype $ldc_shortname},
    not     => 1,
    expect  => [
        qq{Cell $tmp_name already exists with:},
        qq{Location => $location},
        q{Celltype => test},
        q{These can NOT be redefined.},
    ],
);

# Check that we can redefine the parentcell

$test->efs_test_command(
    command => qq{efs define cell $region $campus $location c test $fstype $rdc_shortname},
    expect  => qq{Updated parentcell for $tmp_name to $rdc_name},
);

# All done

$test->efs_test_command(
    command => qq{efs undef cell $tmp_shortname}
);

exit 0;

