#!/usr/bin/env perl

use strict;
use warnings;
use English;

use Test::More qw( no_plan );

use lib q{test/lib};
use EFS::Test;

my $test = EFS::Test->new( as_user => q{efsops} );

my $business = q{testbusiness};

$test->efs_test_command(
    name    => q{Verifying that the business doesn't exist...},
    command => qq{efs display business $business},
    expect  => [ qq{No such business '$business'}, ],
    bail    => 1,
    not     => 1,
);

$test->efs_test_command(
    name    => q{Define a bogus business},
    command => q{efs define business UPPERCASE 'test business'},
    expect  => [
        q{Invalid business 'UPPERCASE'},
        q{Must consist solely of lower case letters (a-z)},
        q{Exit status from efs server not received.  Assuming failure...},
    ],
    not => 1,
);

$test->efs_test_command(
    name    => qq{Define the business '$business'},
    command => qq{efs define business $business temp},
    expect  => [ qq{Defined business $business}, ],
);

$test->efs_test_command(
    name    => qq{Define the business '$business' again},
    command => qq{efs define business $business 'test business'},
    expect  => [
        qq{Business $business is already defined.},
        qq{Updated description of business $business},
    ],
);

$test->efs_test_command(
    name    => q{Set an attribute for the business},
    command => ( qq{efs setattr business $business foo bar}, ),
    expect  => [
        qq{For business '$business', defined attribute as:},
        q{'foo' => 'bar'},
    ],
);

$test->efs_test_command(
    name    => qq{Display the business '$business'},
    command => qq{efs display business $business},
    expect  => [
        qr{Business \s+ Description}msx,
        qr{=+}msx,
        qr{$business \s+ test \s+ business}msx,
        qr{Business \s+ Attribute \s+ Value}msx,
        qr{=+}msx,
        qr{$business \s+ foo \s+ bar}msx,
    ],
);

$test->efs_test_command(
    name    => q{Undefine the business},
    command => qq{efs undef business $business},
    expect  => [ qq{Undefined business $business}, ],
);

$test->efs_test_command(
    name    => q{Check the history entries},
    command => qq{efs history business $business -count 4},
    expect  => [
        qr{History \s+ ID \s+ StartTime \s+ Duration \s+ Status \s+ Authuser \s+ Request}msx,
        qr{-+}msx,
        qr{define \s+ business \s+ $business}msx,
        qr{define \s+ business \s+ $business}msx,
        qr{setattr \s+ business \s+ $business}msx,
        qr{undef \s+ business \s+ $business}msx,
    ],
);

